@@ -1,3 +1,4 @@
+import pathlib
 from dataclasses import dataclass
 from enum import StrEnum
 from typing import Literal
@@ -9,15 +10,17 @@ type IntOrNoLimit = int | Literal["no-limit"]
 class PRSource(StrEnum):
     github = "github"
     gitlab = "gitlab"
+    local = "local"
 
 
-class IssuesSource(StrEnum):
+class IssuesPlatform(StrEnum):
     github = "github"
     gitlab = "gitlab"
+    jira = "jira"
 
     @property
     def is_git_platform(self) -> bool:
-        return self in {IssuesSource.gitlab, IssuesSource.github}
+        return self in {IssuesPlatform.gitlab, IssuesPlatform.github}
 
 
 @dataclass(frozen=True, slots=True)
@@ -28,6 +31,16 @@ class PRUrl:
     source: PRSource
 
 
+@dataclass(frozen=True, slots=True)
+class LocalRepository:
+    repo_path: pathlib.Path
+    source: PRSource = PRSource.local
+
+    @property
+    def full_url(self) -> str:
+        return self.repo_path.as_posix()
+
+
 class OutputFormat(StrEnum):
     pretty = "pretty"
     json = "json"
